Subsystems
==========

Collections of `Components` and/or `Compositions` that implement a model of the mechanism(s) underlying a
particular brain structure, function, psychological process, or set thereof.

.. toctree::
   :maxdepth: 2

   AGT
   EVC
